@@ -25,8 +25,12 @@ ID = 'id'
 SCOPES = 'config_scopes'
 VARS = 'hostvars'
 GROUPS = 'groups'
+REGION = 'region_name'
+AZ = 'availability_zone'
+LAUNCH_TIMEOUT = 'launch_timeout_s'
+POST_DELAY = 'post_launch_delay_s'
 
-# this are ansible magic vars
+# these are ansible magic vars
 INV_NAME = 'inventory_hostname'
 INV_NAME_SHORT = 'inventory_hostname_short'
 GROUP_NAMES = 'group_names'
