@@ -14,6 +14,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with bang.  If not, see <http://www.gnu.org/licenses/>.
+import time
 from .. import attributes as A
 from ..util import log
 from .deployer import Deployer
@@ -23,14 +24,19 @@ class BaseDeployer(Deployer):
     """Base class for all cloud resource deployers"""
     def __init__(self, stack, config, consul):
         super(BaseDeployer, self).__init__(stack, config)
-        self.consul = consul
+        self._consul = consul
+
+    @property
+    def consul(self):
+        return self._consul
 
 
 class RegionedDeployer(BaseDeployer):
     """Deployer that automatically sets its region"""
-    def __init__(self, *args, **kwargs):
-        super(RegionedDeployer, self).__init__(*args, **kwargs)
-        self.consul.set_region(self.region_name)
+    @property
+    def consul(self):
+        self._consul.set_region(self.region_name)
+        return self._consul
 
 
 class ServerDeployer(RegionedDeployer):
@@ -76,10 +82,12 @@ class ServerDeployer(RegionedDeployer):
                 self.instance_type,
                 self.ssh_key_name,
                 tags=self.tags,
-                region_name=self.region_name,
-                timeout_s=getattr(self, 'launch_timeout_s', 0),
+                availability_zone=self.availability_zone,
+                timeout_s=self.launch_timeout_s,
                 security_groups=self.security_groups,
                 )
+        log.debug('Post launch delay: %d s' % self.post_launch_delay_s)
+        time.sleep(self.post_launch_delay_s)
 
     def add_to_inventory(self):
         """Adds host to stack inventory"""
@@ -218,7 +226,7 @@ class DatabaseDeployer(BaseDeployer):
                 self.instance_type,
                 self.admin_username,
                 self.admin_password,
-                db_name=getattr(self, 'db_name', self.name),
+                db_name=self.db_name,
                 storage_size_gb=self.storage_size,
                 timeout_s=self.launch_timeout_s,
                 )
